@@ -1,14 +1,14 @@
 package WebService::Pixabay;
 
-use Modern::Perl '2010';
+use Modern::Perl '2009';
 use Moo;
 use Function::Parameters;
-use Data::Printer;
+use Data::Dumper 'Dumper';
 
 with 'WebService::Client';
 
 # ABSTRACT: Perl 5 interface to Pixabay API.
-our $VERSION = '1.0.1';    our $VERSION = '1.0.1'; # VERSION
+our $VERSION = '2.0.0';    our $VERSION = '2.0.0'; # VERSION
 
 # token key
 has api_key => (
@@ -16,9 +16,6 @@ has api_key => (
     required => 1
 );
 
-# object for holding json data
-has json_data => ( is => 'rw' );
-
 has '+base_url' => ( default => 'https://pixabay.com/api/' );
 
 # get image metadata from JSON
@@ -41,18 +38,14 @@ method image_search(
     : $pretty         = "false"
   )
 {
-    $self->json_data(
-        $self->get(
+	return $self->get(
                 "?key="
               . $self->api_key
               . "&q=$q&lang=$lang&id=$id&response_group=$response_group&image_type=$image_type"
               . "&orientation=$orientation&category=$category&min_width=$min_width&mind_height=$min_height"
               . "&editors_choice=$editors_choice&safesearch=$safesearch&order=$order&page=$page"
               . "&per_page=$per_page&callback=$callback&pretty=$pretty"
-        )
-    );
-
-    return $self;
+        );
 }
 
 # get image metadata from JSON
@@ -73,23 +66,19 @@ method video_search(
     : $pretty         = "false"
   )
 {
-    $self->json_data(
-        $self->get(
+	return $self->get(
                 "videos/?key="
               . $self->api_key
               . "&q=$q&lang=$lang&id=$id&video_type=$video_type"
               . "&category=$category&min_width=$min_width&mind_height=$min_height"
               . "&editors_choice=$editors_choice&safesearch=$safesearch&order=$order&page=$page"
               . "&per_page=$per_page&callback=$callback&pretty=$pretty"
-        )
-    );
-
-    return $self;
+        );
 }
 
 # pretty print the JSON data structure
-method show_data_structure() {
-    return p $self->json_data;
+method show_data_structure($method_name) {
+    print Dumper $method_name;
 }
 
 1;
@@ -106,21 +95,24 @@ WebService::Pixabay - Perl 5 interface to Pixabay API.
 
 =head1 VERSION
 
-version 1.0.1
+version 2.0.0
 
 =head1 SYNOPSIS
 
+	use strict;
+	use warnings;
+
 	use WebService::Pixabay;
 	
 	my $pix = WebService::Pixabay->new(api_key => 'secret');
 	
 	# default searches
-	my $img_search = $pix->image_search();
-	my $vid_search = $pix->video_search();
+	my $img1 = $pix->image_search;
+	my $vid1 = $pix->video_search;
 	
 	# show data structure using Data::Printer pretty print.
-	$img_search->show_data_structure;
-	$vid_search->show_data_structure;
+	$pix->show_data_structure($img1);
+	$pix->show_data_structure($vid1);
 	
 	###################################################
 	# The parameters of the method have the same name #
@@ -128,7 +120,7 @@ version 1.0.1
 	###################################################
 
 	# example custom image search and printing
-	my $nis = $pix->image_search(
+	my $cust_img = $pix->image_search(
 		q => 'cats dog',
 		lang => 'es',
 		response_group => 'high_resolution',
@@ -141,35 +133,35 @@ version 1.0.1
 		pretty => 'true'
 	);
 
-	$nis->show_data_structure;
+	$pix->show_data_structure($cust_img);
 
-	# -or-
+	# -or with video_search-
 
 	# example custom video search and printing
-	my $nvs = $pix->video_search(
+	my $cust_vid = $pix->video_search(
 		q => 'tree',
 		lang => 'en',
 		pretty => 'false',
 		page => 3,
 		order => 'popular'
-	)->show_data_structure;
+	);
 
-	# Handling specific hashes and arrays of values from the JSON
+	$pix->show_data_structure($cust_vid);
+
+	# Handling specific hashes and arrays of values from the image_search JSON
 	# example retrieving webformatURL from each arrays
 	my @urls = undef;
 	
-	# note the 'json_data' object usage
-	foreach my $url (@{$nis->json_data->{hits}}) {
+	foreach my $url (@{$cust_img->{hits}}) {
+
 		# now has link of photo urls (non-preview photos)
 		push(@urls, $url->{webformatURL});		
 	}
 	
-	say $urls[3]; # image URL
+	say $urls[3]; # image URL in the fourth row
 
-	# Getting a specific single hash or array value
-	say $pix->video_search(q => 'fire')
-		->json_data
-		->{hits}[2]{videos}{medium}{url};
+	# Getting a specific single hash or array value from video_search JSON
+	say $cust_vid->{hits}[0]{medium}{url};
 
 =head1 SEE ALSO
 
